@@ -48,7 +48,7 @@ except ImportError:
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_binascii.git"
 
-
+# fmt: off
 TABLE_A2B_B64 = (
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
@@ -67,15 +67,18 @@ TABLE_A2B_B64 = (
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
 )
+# fmt: on
+
+TABLE_B2A_B64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"
 
-TABLE_B2A_B64 = (
-    "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/")
 
 class Error(Exception):
     """Exception raised on errors. These are usually programming errors."""
+
     # pylint: disable=unnecessary-pass
     pass
 
+
 if not "unhexlify" in globals():
     # pylint: disable=function-redefined
     def unhexlify(hexstr):
@@ -104,18 +107,23 @@ if not "hexlify" in globals():
         if not data:
             raise TypeError("Data provided is zero-length")
         data = "".join("%02x" % i for i in data)
-        return bytes(data, 'utf-8')
+        return bytes(data, "utf-8")
+
 
 B2A_HEX = hexlify
 A2B_HEX = unhexlify
 
+
 def _transform(n):
     if n == -1:
-        return '\xff'
+        return "\xff"
     return chr(n)
-TABLE_A2B_B64 = ''.join(map(_transform, TABLE_A2B_B64))
+
+
+TABLE_A2B_B64 = "".join(map(_transform, TABLE_A2B_B64))
 assert len(TABLE_A2B_B64) == 256
 
+
 def a2b_base64(b64_data):
     """Convert a block of base64 data back to binary and return the binary data.
 
@@ -132,12 +140,12 @@ def a2b_base64(b64_data):
         char = chr(char)
         if char == "=":
             if quad_pos > 2 or (quad_pos == 2 and last_char_was_a_pad):
-                break      # stop on 'xxx=' or on 'xx=='
+                break  # stop on 'xxx=' or on 'xx=='
             last_char_was_a_pad = True
         else:
             n = ord(TABLE_A2B_B64[ord(char)])
-            if n == 0xff:
-                continue    # ignore strange characters
+            if n == 0xFF:
+                continue  # ignore strange characters
             #
             # Shift it in on the low end, and see if there's
             # a byte ready for output.
@@ -147,15 +155,16 @@ def a2b_base64(b64_data):
             #
             if leftbits >= 8:
                 leftbits -= 8
-                res.append((leftchar >> leftbits).to_bytes(1, 'big'))
-                leftchar &= ((1 << leftbits) - 1)
+                res.append((leftchar >> leftbits).to_bytes(1, "big"))
+                leftchar &= (1 << leftbits) - 1
             #
             last_char_was_a_pad = False
     else:
         if leftbits != 0:
             raise Exception("Incorrect padding")
 
-    return b''.join(res)
+    return b"".join(res)
+
 
 def b2a_base64(bin_data):
     """Convert binary data to a line of ASCII characters in base64 coding.
@@ -173,10 +182,10 @@ def b2a_base64(bin_data):
         # Shift into our buffer, and output any 6bits ready
         leftchar = (leftchar << 8) | char
         leftbits += 8
-        res.append(TABLE_B2A_B64[(leftchar >> (leftbits-6)) & 0x3f])
+        res.append(TABLE_B2A_B64[(leftchar >> (leftbits - 6)) & 0x3F])
         leftbits -= 6
         if leftbits >= 6:
-            res.append(TABLE_B2A_B64[(leftchar >> (leftbits-6)) & 0x3f])
+            res.append(TABLE_B2A_B64[(leftchar >> (leftbits - 6)) & 0x3F])
             leftbits -= 6
     #
     if leftbits == 2:
@@ -184,7 +193,7 @@ def b2a_base64(bin_data):
         res.append("=")
         res.append("=")
     elif leftbits == 4:
-        res.append(TABLE_B2A_B64[(leftchar & 0xf) << 2])
+        res.append(TABLE_B2A_B64[(leftchar & 0xF) << 2])
         res.append("=")
-    res.append('\n')
-    return bytes(''.join(res), 'ascii')
+    res.append("\n")
+    return bytes("".join(res), "ascii")
